@@ -1,12 +1,12 @@
 /* echo-area.c -- how to read a line in the echo area.
-   $Id: echo-area.c,v 1.6 2004/12/08 16:49:48 karl Exp $
+   $Id: echo-area.c,v 1.7.2.1 2007/06/27 17:10:56 karl Exp $
 
-   Copyright (C) 1993, 1997, 1998, 1999, 2001, 2004 Free Software
+   Copyright (C) 1993, 1997, 1998, 1999, 2001, 2004, 2007 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -936,7 +936,8 @@ DECLARE_INFO_COMMAND (ea_possible_completions, _("List possible completions"))
       printf_to_message_buffer (completions_found_index == 1
                                 ? (char *) _("One completion:\n")
                                 : (char *) _("%d completions:\n"),
-				(void*) (completions_found_index), NULL, NULL);
+				(void *) (long) completions_found_index,
+				NULL, NULL);
 
       /* Find the maximum length of a label. */
       for (i = 0; i < completions_found_index; i++)
