@@ -1,12 +1,12 @@
 /* filesys.c -- filesystem specific functions.
-   $Id: filesys.c,v 1.3 2004/03/14 00:57:29 karl Exp $
+   $Id: filesys.c,v 1.6.2.1 2007/06/27 17:10:56 karl Exp $
 
-   Copyright (C) 1993, 1997, 1998, 2000, 2002, 2003, 2004 Free Software
+   Copyright (C) 1993, 1997, 1998, 2000, 2002, 2003, 2004, 2007 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -281,13 +281,13 @@ extract_colon_unit (char *string, int *idx)
   if (!string || i >= strlen (string))
     return NULL;
 
+  if (!string[i]) /* end of string */
+    return NULL;
+
   /* Advance to next PATH_SEP.  */
   while (string[i] && string[i] != PATH_SEP[0])
     i++;
 
-  if (!string[i] && i == start) /* end of string, and didn't advance */
-    return NULL;
-
   {
     char *value = xmalloc ((i - start) + 1);
     strncpy (value, &string[start], (i - start));
