@@ -1,12 +1,12 @@
 /* info.c -- Display nodes of Info files in multiple windows.
-   $Id: info.c,v 1.7 2004/03/13 15:52:46 dirt Exp $
+   $Id: info.c,v 1.11.2.2 2007/06/27 17:10:57 karl Exp $
 
    Copyright (C) 1993, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-   2004 Free Software Foundation, Inc.
+   2004, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -291,10 +291,11 @@ main (int argc, char **argv)
     {
       printf ("%s (GNU %s) %s\n", program_name, PACKAGE, VERSION);
       puts ("");
-      puts ("Copyright (C) 2004 Free Software Foundation, Inc.");
-      printf (_("There is NO warranty.  You may redistribute this software\n\
-under the terms of the GNU General Public License.\n\
-For more information about these matters, see the files named COPYING.\n"));
+      printf (_("Copyright (C) %s Free Software Foundation, Inc.\n\
+License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
+This is free software: you are free to change and redistribute it.\n\
+There is NO WARRANTY, to the extent permitted by law.\n"),
+	      "2007");
       xexit (0);
     }
 
