@@ -1,12 +1,12 @@
 /* files.c -- file-related functions for makeinfo.
-   $Id: files.c,v 1.15 2004/02/28 10:42:50 dirt Exp $
+   $Id: files.c,v 1.5.2.1 2007/06/27 17:11:00 karl Exp $
 
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2007 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -183,9 +183,12 @@ pop_path_from_include_path (void)
 }
 
 /* Find and load the file named FILENAME.  Return a pointer to
-   the loaded file, or NULL if it can't be loaded. */
+   the loaded file, or NULL if it can't be loaded.  If USE_PATH is zero,
+   just look for the given file (this is used in handle_delayed_writes),
+   else search along include_files_path.   */
+
 char *
-find_and_load (char *filename)
+find_and_load (char *filename, int use_path)
 {
   struct stat fileinfo;
   long file_size;
@@ -195,7 +198,9 @@ find_and_load (char *filename)
 
   result = fullpath = NULL;
 
-  fullpath = get_file_info_in_path (filename, include_files_path, &fileinfo);
+  fullpath
+    = get_file_info_in_path (filename, use_path ? include_files_path : NULL, 
+                             &fileinfo);
 
   if (!fullpath)
     goto error_exit;
@@ -682,7 +687,7 @@ handle_delayed_writes (void)
 
   while (temp)
     {
-      delayed_buf = find_and_load (temp->filename);
+      delayed_buf = find_and_load (temp->filename, 0);
 
       if (output_paragraph_offset > 0)
         {
