@@ -1,11 +1,11 @@
 /* files.h -- declarations for files.c.
-   $Id: files.h,v 1.7 2004/02/28 10:42:50 dirt Exp $
+   $Id: files.h,v 1.4.2.1 2007/06/27 17:11:00 karl Exp $
 
-   Copyright (C) 1998, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1998, 2002, 2004, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -39,7 +39,7 @@ extern void popfile (void);
 extern void flush_file_stack (void);
 extern char *get_file_info_in_path (char *filename, char *path,
     struct stat *finfo);
-extern char *find_and_load (char *filename);
+extern char *find_and_load (char *filename, int use_path);
 extern char *output_name_from_input_name (char *name);
 extern char *expand_filename (char *filename, char *input_name);
 extern char *filename_part (char *filename);
