@@ -1,11 +1,11 @@
 /* footnote.c -- footnotes for Texinfo.
-   $Id: footnote.c,v 1.6 2004/03/01 15:28:06 dirt Exp $
+   $Id: footnote.c,v 1.7.2.1 2007/06/27 17:11:01 karl Exp $
 
-   Copyright (C) 1998, 1999, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2002, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -298,7 +298,7 @@ output_pending_notes (void)
       /* We add an anchor here so @printindex can refer to this point
          (as the node name) for entries defined in footnotes.  */
       if (!splitting)
-        add_word_args ("<a name=\"%s\"></a>", _("Footnotes"));
+        add_word ("<a name=\"texinfo-footnotes-in-document\"></a>");
       add_word_args ("<h4>%s</h4>", (char *) _("Footnotes"));
     }
   else
