@@ -1,12 +1,12 @@
 /* index.c -- indexing for Texinfo.
-   $Id: index.c,v 1.21 2004/03/14 22:47:19 karl Exp $
+   $Id: index.c,v 1.17.2.1 2007/06/27 17:11:01 karl Exp $
 
-   Copyright (C) 1998, 1999, 2002, 2003, 2004 Free Software Foundation,
+   Copyright (C) 1998, 1999, 2002, 2003, 2004, 2007 Free Software Foundation,
    Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -180,8 +180,8 @@ index_add_arg (char *name)
         flush_output ();
 
       new->next = the_indices[which];
-      new->entry_text = index_entry;
       new->entry = NULL;
+      new->entry_text = index_entry;
       /* Since footnotes are handled at the very end of the document,
          node name in the non-split HTML outputs always show the last
          node.  We artificially make it ``Footnotes''.  */
@@ -197,6 +197,11 @@ index_add_arg (char *name)
           else
             new->section_name = "";
         }
+      else
+        {
+          new->section = NULL;
+          new->section_name = NULL;
+        }
       new->code = tem->code;
       new->defining_line = line_number - 1;
       new->output_line = no_headers ? output_line_number : node_line_number;
@@ -204,9 +209,6 @@ index_add_arg (char *name)
          something that goes away, for example, inside a macro.
          (see the findexerr test).  */
       new->defining_file = xstrdup (input_filename);
-      the_indices[which] = new;
-
-      new->entry_number = index_counter;
 
       if (html && splitting)
         {
@@ -215,6 +217,11 @@ index_add_arg (char *name)
           else
             new->output_file = xstrdup ("");
         }
+      else
+        new->output_file = NULL;        
+
+      new->entry_number = index_counter;
+      the_indices[which] = new;
 
 #if 0
       /* The index breaks if there are colons in the entry.
@@ -240,7 +247,7 @@ index_add_arg (char *name)
             removed_empty_elt = 2;
 
           add_word ("<a name=\"index-");
-          add_escaped_anchor_name (index_entry);
+          add_escaped_anchor_name (index_entry, 0);
           add_word_args ("-%d\"></a>", index_counter);
 
           if (removed_empty_elt == 1)
@@ -653,12 +660,12 @@ insert_index_output_line_no (int line_number, int output_line_number_len)
   int last_column;
   int str_size = output_line_number_len + strlen (_("(line )"))
     + sizeof (NULL);
-  char *out_line_no_str = (char *) xmalloc (str_size);
+  char *out_line_no_str = (char *) xmalloc (str_size + 1);
 
   /* Do not translate ``(line NNN)'' below for !no_headers case (Info output),
      because it's something like the ``* Menu'' strings.  For plaintext output
      it should be translated though.  */
-  snprintf (out_line_no_str, str_size,
+  sprintf (out_line_no_str,
       no_headers ? _("(line %*d)") : "(line %*d)",
       output_line_number_len, line_number);
 
@@ -713,13 +720,13 @@ cm_printindex (void)
   else if (!handling_delayed_writes)
     {
       int command_len = sizeof ("@ ") + strlen (command) + strlen (index_name);
-      char *index_command = xmalloc (command_len);
+      char *index_command = xmalloc (command_len + 1);
 
       close_paragraph ();
       if (docbook)
         xml_begin_index ();
 
-      snprintf (index_command, command_len, "@%s %s", command, index_name);
+      sprintf (index_command, "@%s %s", command, index_name);
       register_delayed_write (index_command);
       free (index_command);
     }
@@ -781,15 +788,14 @@ cm_printindex (void)
         char *max_output_line_number = (char *) xmalloc (25 * sizeof (char));
 
         if (no_headers)
-          snprintf (max_output_line_number, 25 * sizeof (char), "%d",
-              output_line_number);
+          sprintf (max_output_line_number, "%d", output_line_number);
         else
           {
             INDEX_ELT *tmp_entry = index;
             unsigned tmp = 0;
             for (tmp_entry = index; tmp_entry; tmp_entry = tmp_entry->next)
               tmp = tmp_entry->output_line > tmp ? tmp_entry->output_line : tmp;
-            snprintf (max_output_line_number, 25 * sizeof (char), "%d", tmp);
+            sprintf (max_output_line_number, "%d", tmp);
           }
 
         output_line_number_len = strlen (max_output_line_number);
@@ -817,33 +823,28 @@ cm_printindex (void)
             }
 
           if (html)
-            /* fixme: html: we should use specific index anchors pointing
-           to the actual location of the indexed position (but then we
-           have to find something to wrap the anchor around). */
             {
-              /* In the HTML case, the expanded index entry is not
-                 good for us, since it was expanded for non-HTML mode
-                 inside sort_index.  So we need to HTML-escape and
-                 expand the original entry text here.  */
-              char *escaped_entry = xstrdup (index->entry_text);
-              char *expanded_entry;
+              /* For HTML, we need to expand and HTML-escape the
+                 original entry text, at the same time.  Consider
+                 @cindex J@"urgen.  We want J&uuml;urgen.  We can't
+                 expand and then escape since we'll end up with
+                 J&amp;uuml;rgen.  We can't escape and then expand
+                 because then `expansion' will see J@&quot;urgen, and
+                 @&quot;urgen is not a command.  */
+              char *html_entry =
+                maybe_escaped_expansion (index->entry_text, index->code, 1);
 
-              /* expansion() doesn't HTML-escape the argument, so need
-                 to do it separately.  */
-              escaped_entry = escape_string (escaped_entry);
-              expanded_entry = expansion (escaped_entry, index->code);
               add_html_block_elt_args ("\n<li><a href=\"%s#index-",
-                  (splitting ? index->output_file : ""), index_name);
-              add_escaped_anchor_name (index->entry_text);
+                  (splitting && index->output_file) ? index->output_file : "");
+              add_escaped_anchor_name (index->entry_text, 0);
               add_word_args ("-%d\">%s</a>: ", index->entry_number,
-                  expanded_entry);
-              free (escaped_entry);
-              free (expanded_entry);
+                  html_entry);
+              free (html_entry);
 
               add_word ("<a href=\"");
               if (index->node && *index->node)
                 {
-                  /* Make sure any non-macros in the node name are expanded.  */
+                  /* Ensure any non-macros in the node name are expanded.  */
                   char *expanded_index;
 
                   in_fixed_width_font++;
