@@ -1,12 +1,12 @@
 /* insertion.c -- insertions for Texinfo.
-   $Id: insertion.c,v 1.38 2004/04/06 21:27:32 dirt Exp $
+   $Id: insertion.c,v 1.55.2.1 2007/06/27 17:11:01 karl Exp $
 
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2007 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -510,6 +510,7 @@ begin_insertion (enum insertion_type type)
         /* Save the copying text away for @insertcopying,
            typically used on the back of the @titlepage (for TeX) and
            the Top node (for info/html).  */
+      if (input_text[input_text_offset] != '\n')
         discard_until ("\n"); /* ignore remainder of @copying line */
 
         input_text_offset = get_until ("\n@end copying", &copying_text);
@@ -1048,7 +1049,9 @@ end_insertion (int type)
     {
       /* Insertions which have no effect on paragraph formatting. */
     case copying:
-    case documentdescription:
+      line_number--;
+      break;
+
     case ifclear:
     case ifdocbook:
     case ifinfo:
@@ -1100,6 +1103,12 @@ end_insertion (int type)
       close_insertion_paragraph ();
       break;
 
+    case documentdescription:
+      if (xml)
+        insert_string (document_description);
+        xml_insert_element (DOCUMENTDESCRIPTION, END);
+      break;
+      
     case menu:
       in_menu--;                /* No longer hacking menus. */
       if (html && !no_headers)
@@ -1544,8 +1553,15 @@ cm_direntry (void)
 void
 cm_documentdescription (void)
 {
-  if (html || xml)
+  if (html)
     begin_insertion (documentdescription);
+
+  else if (xml)
+    {
+      xml_insert_element (DOCUMENTDESCRIPTION, START);
+      begin_insertion (documentdescription);
+    }
+
   else
     command_name_condition ();
 }
