@@ -1,12 +1,12 @@
 /* makeinfo.h -- declarations for Makeinfo.
-   $Id: makeinfo.h,v 1.8 2004/03/10 22:34:21 dirt Exp $
+   $Id: makeinfo.h,v 1.17.2.1 2007/06/27 17:11:02 karl Exp $
 
-   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 Free
+   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2007 Free
    Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -269,8 +269,15 @@ DECLARE (int, expensive_validation, 0);
 #define digit_value(c) ((c) - '0')
 #endif
 
-/* #define HTML_SAFE "$-_.+!*'()" */
-/* #define URL_SAFE_CHAR(ch) (isalnum (ch) || strchr (HTML_SAFE, ch)) */
+/* These characters are not really HTML-safe (with strict XHTML),
+   and also there are possible collisions.  That's the whole reason we
+   designed a new conversion scheme in the first place.  But we
+   nevertheless need to generate the old names.  See
+   `add_escaped_anchor_name' in html.c.  */
+#define OLD_HTML_SAFE "$-_.+!*'()"
+#define OLD_URL_SAFE_CHAR(ch) (strchr (OLD_HTML_SAFE, ch))
+
+/* For the current/stable scheme.  */
 #define URL_SAFE_CHAR(ch) (isalnum (ch))
 
 #define COMMAND_PREFIX '@'
@@ -316,6 +323,7 @@ extern GENERIC_LIST * reverse_list (GENERIC_LIST *list);
 extern char *info_trailer (void),
   *expansion (char *str, int implicit_code),
   *text_expansion (char *str),
+  *maybe_escaped_expansion (char *str, int implicit_code, int do_escape_html),
   *full_expansion (char *str, int implicit_code);
 
 extern void free_and_clear (char **pointer),
@@ -323,7 +331,7 @@ extern void free_and_clear (char **pointer),
   add_char (int character),
   add_meta_char (int character),
   close_single_paragraph (void),
-  insert_string (char *string),
+  insert_string (const char *),
   insert (int character),
   get_rest_of_line (int expand, char **string),
   add_html_block_elt (char *string),
