@@ -1,12 +1,12 @@
 /* node.c -- nodes for Texinfo.
-   $Id: node.c,v 1.25 2004/11/30 13:26:50 karl Exp $
+   $Id: node.c,v 1.27.2.1 2007/06/27 17:11:02 karl Exp $
 
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2007 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -520,6 +520,7 @@ add_html_names (char *node)
   }
 
   /* Always output the new scheme.  */
+  canon_white (tem);
   add_word ("<a name=\"");
   add_anchor_name (tem, 0);
   add_word ("\"></a>\n");
@@ -978,13 +979,11 @@ cm_node (void)
           /* The <p> avoids the links area running on with old Lynxen. */
           add_word_args ("<p>%s\n", splitting ? "" : "<hr>");
 
-          /* In the split HTML case, there's no point in adding the
-             old-style converted names, since the filename is wrong.  */
-          tem = expand_node_name (node);
-          add_word ("<a name=\"");
-          add_anchor_name (tem, 0);
-          add_word ("\"></a>\n");
-          free (tem);
+          /* In the split HTML case, the filename is wrong for the 
+             old-style converted names, but we'll add them anyway, for
+             consistency.  (And we need them in the normal (not
+             no_headers) nonsplit case.)  */
+          add_html_names (node);
 
           if (next)
             {
@@ -1666,7 +1665,7 @@ static char *
 enumerate_filename (char *pathname, char *basename, int number)
 {
   /* Do we need to generate names of subfiles which don't exceed 8+3 limits? */
-  static const int dos_file_names = !HAVE_LONG_FILENAMES (pathname ? pathname : ".");
+  const int dos_file_names = !HAVE_LONG_FILENAMES (pathname ? pathname : ".");
   unsigned name_len = strlen (basename);
   char *filename = xmalloc (10 + strlen (pathname) + name_len);
   char *base_filename = xmalloc (10 + name_len);
